
# Slot: expresses


holds between an anatomical entity and gene or gene product that is expressed there

URI: [biolink:expresses](https://w3id.org/biolink/vocab/expresses)


## Domain and Range

[AnatomicalEntity](AnatomicalEntity.md) &#8594;  <sub>0..\*</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002292 |
|  | | hetio:EXPRESSES_AeG |

